@@ -1,5 +1,5 @@
 """
-Copyright  2016-2019 Maël Azimi <m.a@moul.re>
+Copyright  2016-2020 Maël Azimi <m.a@moul.re>
 
 Silkaj is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
@@ -15,14 +15,24 @@ You should have received a copy of the GNU Affero General Public License
 along with Silkaj. If not, see <https://www.gnu.org/licenses/>.
 """
 
-from silkaj.tools import message_exit
+import re
 from click import command, option, pass_context, confirm
 from getpass import getpass
 from pathlib import Path
-from re import compile, search, MULTILINE
+
 from duniterpy.key import SigningKey
 from duniterpy.key.scrypt_params import ScryptParams
 
+# had to import display_pubkey_and_checksum from wot to avoid loop dependency.
+from silkaj.wot import display_pubkey_and_checksum
+from silkaj.tools import message_exit
+from silkaj.constants import PUBKEY_PATTERN
+
+
+SEED_HEX_PATTERN = "^[0-9a-fA-F]{64}$"
+PUBSEC_PUBKEY_PATTERN = "pub: ({0})".format(PUBKEY_PATTERN)
+PUBSEC_SIGNKEY_PATTERN = "sec: ([1-9A-HJ-NP-Za-km-z]{87,90})"
+
 
 @pass_context
 def auth_method(ctx):
@@ -36,17 +46,28 @@ def auth_method(ctx):
         return auth_by_scrypt()
 
 
+@pass_context
+def has_auth_method(ctx):
+    return (
+        ctx.obj["AUTH_SCRYPT"]
+        or ctx.obj["AUTH_FILE"]
+        or ctx.obj["AUTH_SEED"]
+        or ctx.obj["AUTH_WIF"]
+    )
+
+
 @command("authfile", help="Generate authentication file")
 @option("--file", default="authfile", show_default=True, help="Path file")
 def generate_auth_file(file):
     key = auth_method()
     authfile = Path(file)
+    pubkey_cksum = display_pubkey_and_checksum(key.pubkey)
     if authfile.is_file():
         confirm(
             "Would you like to erase "
             + file
             + " by an authfile corresponding to following pubkey `"
-            + key.pubkey
+            + pubkey_cksum
             + "`?",
             abort=True,
         )
@@ -54,34 +75,33 @@ def generate_auth_file(file):
     print(
         "Authentication file 'authfile' generated and stored in current\
  folder for following public key:",
-        key.pubkey,
+        pubkey_cksum,
     )
 
 
 @pass_context
 def auth_by_auth_file(ctx):
     """
-    Uses an auth file to generate key.
-    Authfile can be either:
-    * Seed in hexadecimal encoding
-    * PubSec format with public and private key in base58 encoding.
+    Uses an authentication file to generate the key
+    Authfile can either be:
+    * A seed in hexadecimal encoding
+    * PubSec format with public and private key in base58 encoding
     """
     file = ctx.obj["AUTH_FILE_PATH"]
     authfile = Path(file)
     if not authfile.is_file():
         message_exit('Error: the file "' + file + '" does not exist')
     filetxt = authfile.open("r").read()
-    # regex for seed (hexadecimal)
-    regex_seed = compile("^[0-9a-fA-F]{64}$")
-    # two RE for PubSec format
-    regex_pubkey = compile("pub: ([1-9A-HJ-NP-Za-km-z]{43,44})", MULTILINE)
-    regex_signkey = compile("sec: ([1-9A-HJ-NP-Za-km-z]{87,90})", MULTILINE)
 
-    # Seed Format
-    if search(regex_seed, filetxt):
+    # two regural expressions for the PubSec format
+    regex_pubkey = re.compile(PUBSEC_PUBKEY_PATTERN, re.MULTILINE)
+    regex_signkey = re.compile(PUBSEC_SIGNKEY_PATTERN, re.MULTILINE)
+
+    # Seed hexadecimal format
+    if re.search(re.compile(SEED_HEX_PATTERN), filetxt):
         return SigningKey.from_seedhex_file(file)
     # PubSec format
-    elif search(regex_pubkey, filetxt) and search(regex_signkey, filetxt):
+    elif re.search(regex_pubkey, filetxt) and re.search(regex_signkey, filetxt):
         return SigningKey.from_pubsec_file(file)
     else:
         message_exit("Error: the format of the file is invalid")
