@@ -1,5 +1,5 @@
 """
-Copyright  2016-2019 Maël Azimi <m.a@moul.re>
+Copyright  2016-2020 Maël Azimi <m.a@moul.re>
 
 Silkaj is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
@@ -33,3 +33,19 @@ class BlockchainParams(object):
     async def get_params(self):
         client = ClientInstance().client
         return await client(blockchain.parameters)
+
+
+class HeadBlock(object):
+    __instance = None
+
+    def __new__(cls):
+        if HeadBlock.__instance is None:
+            HeadBlock.__instance = object.__new__(cls)
+        return HeadBlock.__instance
+
+    def __init__(self):
+        self.head_block = self.get_head()
+
+    async def get_head(self):
+        client = ClientInstance().client
+        return await client(blockchain.current)
