@@ -1,5 +1,5 @@
 """
-Copyright  2016-2019 Maël Azimi <m.a@moul.re>
+Copyright  2016-2020 Maël Azimi <m.a@moul.re>
 
 Silkaj is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
@@ -15,12 +15,19 @@ You should have received a copy of the GNU Affero General Public License
 along with Silkaj. If not, see <https://www.gnu.org/licenses/>.
 """
 
-from click import command, argument, pass_context
+from click import command, argument, pass_context, echo
+from tabulate import tabulate
 
-from silkaj.network_tools import ClientInstance, HeadBlock
+from silkaj.network_tools import ClientInstance
+from silkaj.blockchain_tools import HeadBlock
 from silkaj.tools import CurrencySymbol, message_exit, coroutine
-from silkaj.auth import auth_method
-from silkaj.wot import check_public_key
+from silkaj.auth import auth_method, has_auth_method
+
+# had to import wot to prevent loop dependency. No use here.
+from silkaj import wot
+from silkaj.crypto_tools import check_pubkey_format, validate_checksum
+from silkaj.tui import display_amount, display_pubkey_and_checksum
+
 from duniterpy.api.bma import tx, blockchain
 from duniterpy.documents.transaction import InputSource
 
@@ -31,25 +38,22 @@ from duniterpy.documents.transaction import InputSource
 @coroutine
 async def cmd_amount(ctx, pubkeys):
     client = ClientInstance().client
-    if not (
-        ctx.obj["AUTH_SCRYPT"]
-        or ctx.obj["AUTH_FILE"]
-        or ctx.obj["AUTH_SEED"]
-        or ctx.obj["AUTH_WIF"]
-    ):
+    if not has_auth_method():
         if not pubkeys:
             message_exit("You should specify one or many pubkeys")
+        pubkey_list = list()
         for pubkey in pubkeys:
-            pubkey = check_public_key(pubkey, True)
-            if not pubkey:
-                return
+            if check_pubkey_format(pubkey):
+                pubkey_list.append(validate_checksum(pubkey))
+            else:
+                pubkey_list.append(pubkey)
         total = [0, 0]
-        for pubkey in pubkeys:
-            value = await get_amount_from_pubkey(pubkey)
-            await show_amount_from_pubkey(pubkey, value)
-            total[0] += value[0]
-            total[1] += value[1]
-        if len(pubkeys) > 1:
+        for pubkey in pubkey_list:
+            inputs_balance = await get_amount_from_pubkey(pubkey)
+            await show_amount_from_pubkey(pubkey, inputs_balance)
+            total[0] += inputs_balance[0]
+            total[1] += inputs_balance[1]
+        if len(pubkey_list) > 1:
             await show_amount_from_pubkey("Total", total)
     else:
         key = auth_method()
@@ -58,51 +62,35 @@ async def cmd_amount(ctx, pubkeys):
     await client.close()
 
 
-async def show_amount_from_pubkey(pubkey, value):
-    totalAmountInput = value[0]
-    amount = value[1]
+async def show_amount_from_pubkey(pubkey, inputs_balance):
+    totalAmountInput = inputs_balance[0]
+    balance = inputs_balance[1]
     currency_symbol = await CurrencySymbol().symbol
     ud_value = await UDValue().ud_value
     average, monetary_mass = await get_average()
-    if totalAmountInput - amount != 0:
-        print("Blockchain:")
-        print("-----------")
-        print("Relative     =", round(amount / ud_value, 2), "UD", currency_symbol)
-        print("Quantitative =", round(amount / 100, 2), currency_symbol + "\n")
-
-        print("Pending Transaction:")
-        print("--------------------")
-        print(
-            "Relative     =",
-            round((totalAmountInput - amount) / ud_value, 2),
-            "UD",
+    # if `pubkey` is a pubkey, get pubkey:checksum
+    if pubkey != "Total":
+        pubkey = display_pubkey_and_checksum(pubkey)
+    # display balance table
+    display = list()
+    display.append(["Balance of pubkey", pubkey])
+    if totalAmountInput - balance != 0:
+        display_amount(display, "Blockchain", balance, ud_value, currency_symbol)
+        display_amount(
+            display,
+            "Pending transaction",
+            (totalAmountInput - balance),
+            ud_value,
             currency_symbol,
         )
-        print(
-            "Quantitative =",
-            round((totalAmountInput - amount) / 100, 2),
-            currency_symbol + "\n",
-        )
-
-    print("Total amount of: " + pubkey)
-    print("----------------------------------------------------------------")
-    print(
-        "Total Relative     =",
-        round(totalAmountInput / ud_value, 2),
-        "UD",
-        currency_symbol,
-    )
-    print("Total Quantitative =", round(totalAmountInput / 100, 2), currency_symbol)
-    print(
-        "Total Relative to average money share =",
-        round(totalAmountInput / average, 2),
-        "× M/N",
-    )
-    print(
-        "Total Relative to monetary mass       =",
-        round((totalAmountInput / monetary_mass) * 100, 3),
-        "% M" + "\n",
+    display_amount(display, "Total amount", totalAmountInput, ud_value, currency_symbol)
+    display.append(
+        [
+            "Total relative to M/N",
+            "{0} x M/N".format(round(totalAmountInput / average, 2)),
+        ]
     )
+    echo(tabulate(display, tablefmt="fancy_grid"))
 
 
 async def get_average():
