@@ -1,5 +1,5 @@
 """
-Copyright  2016-2019 Maël Azimi <m.a@moul.re>
+Copyright  2016-2020 Maël Azimi <m.a@moul.re>
 
 Silkaj is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
@@ -15,31 +15,14 @@ You should have received a copy of the GNU Affero General Public License
 along with Silkaj. If not, see <https://www.gnu.org/licenses/>.
 """
 
-from datetime import datetime
 from sys import exit
 from asyncio import get_event_loop
 from functools import update_wrapper
 
-from silkaj.constants import G1_SYMBOL, GTEST_SYMBOL
+from silkaj.constants import G1_SYMBOL, GTEST_SYMBOL, FAILURE_EXIT_STATUS
 from silkaj.blockchain_tools import BlockchainParams
 
 
-def convert_time(timestamp, kind):
-    ts = int(timestamp)
-    date = "%Y-%m-%d"
-    hour = "%H:%M"
-    second = ":%S"
-    if kind == "all":
-        pattern = date + " " + hour + second
-    elif kind == "date":
-        pattern = date
-    elif kind == "hour":
-        pattern = hour
-        if ts >= 3600:
-            pattern += second
-    return datetime.fromtimestamp(ts).strftime(pattern)
-
-
 class CurrencySymbol(object):
     __instance = None
 
@@ -61,7 +44,7 @@ class CurrencySymbol(object):
 
 def message_exit(message):
     print(message)
-    exit(1)
+    exit(FAILURE_EXIT_STATUS)
 
 
 def coroutine(f):
